@@ -1,5 +1,3 @@
-from urllib import quote
-
 from pydap.model import *
 from pydap.model import typemap
 from pydap.lib import INDENT, encode_atom, isiterable
@@ -46,7 +44,7 @@ def _dataset(var, level=0):
 
 
 def _structure(var, level=0):
-    yield '%s%s {\n' % (level * INDENT, quote(var.name))
+    yield '%s%s {\n' % (level * INDENT, var.name)
 
     for attr, values in var.attributes.items():
         for line in _recursive_build(attr, values, level):
@@ -59,7 +57,7 @@ def _structure(var, level=0):
 
 
 def _base(dapvar, level=0):
-    yield '%s%s {\n' % (level * INDENT, quote(dapvar.name))
+    yield '%s%s {\n' % (level * INDENT, dapvar.name)
 
     for attr, values in dapvar.attributes.items():
         for line in _recursive_build(attr, values, level):
