@@ -1,5 +1,3 @@
-from urllib import quote
-
 from pydap.model import *
 from pydap.lib import INDENT
 from pydap.responses.lib import BaseResponse
@@ -15,7 +13,7 @@ class DDSResponse(BaseResponse):
 
     @staticmethod
     def serialize(dataset):
-        output = ''.join(dispatch(dataset))
+        output = ''.join(dispatch(dataset)).encode("utf-8")
         if hasattr(dataset, 'close'): dataset.close()
         return [output]
 
@@ -40,7 +38,7 @@ def structure_builder(name):
         for child in var.walk():
             for line in dispatch(child, level=level+1):
                 yield line
-        yield '%s} %s;\n' % (level * INDENT, quote(var.name))
+        yield '%s} %s;\n' % (level * INDENT, var.name)
     return func
 
 
@@ -56,7 +54,7 @@ def _grid(var, level=0):
         for line in _base(map_, level=level+2):
             yield line
 
-    yield '%s} %s;\n' % (level * INDENT, quote(var.name))
+    yield '%s} %s;\n' % (level * INDENT, var.name)
 
 
 def _base(var, level=0):
@@ -64,8 +62,8 @@ def _base(var, level=0):
         dims = ['%s = %d' % dim for dim in zip(var.dimensions, var.shape)]
     else:
         if len(var.shape) == 1:
-            dims = ['%s = %d' % (quote(var.name), var.shape[0])]
+            dims = ['%s = %d' % (var.name, var.shape[0])]
         else:
             dims = ['%d' % i for i in var.shape]
     shape = dims and '[%s]' % ']['.join(dims) or ''
-    yield '%s%s %s%s;\n' % (level * INDENT, var.type.descriptor, quote(var.name), shape)
+    yield '%s%s %s%s;\n' % (level * INDENT, var.type.descriptor, var.name, shape)
