@@ -31,7 +31,7 @@ locally, and then return the requested slice (which now is contained
 in the cached data). If the node E is already in the cache we can
 request D instead of B, to minimize downloaded data. 
 
-(c) 2011-2012 Roberto De Almeida <roberto@dealmeida.net>
+(c) 2011-2012 Roberto De Almeida, Guilherme Castelao
 
 """
 from __future__ import division
@@ -110,12 +110,18 @@ class DapCache(object):
                 if last_modified > mtime:
                     os.unlink(cachepath)
 
-            # replace ArrayProxy with a caching version
+            # replace data with a caching version
             for var in walk(dataset, BaseType):
                 var.data = CachingArrayProxy(
                         cachepath, self.tilesize, self.maxsize,
                         var.type, var.id,
                         var.data.url, var.data.shape, var.data._slice)
+            #for var in walk(dataset, SequenceType):
+            #    var.data = CachingSequenceProxy(
+            #            cachepath,
+            #            var.id,
+            #            var.data.url, var.data.slice, var.data._slice, var.data.children)
+
             app = SimpleHandler(dataset)
         # pass this upstream
         else:
