@@ -26,14 +26,17 @@ class DapPacker(object):
                 for line in DapPacker(child):
                     yield line
         else:
-            # Make data iterable and put in blocks.
+            # Get data...
             if getattr(self.var.data, 'shape', False):
                 data = self.var.data
             else:
                 data = numpy.asarray(self.var.data)
+            # ...and give it iterable blocks:
             if len(data.shape) < 2:
-                try: data.shape = (1,-1)
-                except: pass  # arrayterator.shape is ro
+                try:
+                    data.shape = (1, -1)
+                except:
+                    pass
 
             # Yield length (twice) if array.
             if getattr(self.var, 'shape', None):
@@ -140,7 +143,7 @@ class DapUnpacker(object):
                 out = numpy.fromstring(self._buf[i:j], dtype=dtype)
 
             if getattr(self.var, 'shape', False):
-                out.shape = tuple(idx for idx in self.var.shape if idx != 1)
+                out.shape = self.var.shape
             else:   
                 out = out[0]
 
